@@ -1,7 +1,8 @@
 .onLoad <- function(libname, pkgname) {
   inRCmdCheck <- import_future("inRCmdCheck")
   if (inRCmdCheck()) {
-    Sys.setenv("R_FUTURE_CACHE_PATH" = file.path(tempdir(), ".future"))
+    path <- Sys.getenv("R_FUTURE_CACHE_PATH", file.path(tempdir(), ".future"))
+    Sys.setenv("R_FUTURE_CACHE_PATH" = path)
   }
 }
 
@@ -26,3 +27,8 @@
     try(removeDirectory(path, recursive=FALSE, mustExist=FALSE), silent=TRUE)
   }
 }
+
+
+.onAttach <- function(libname, pkgname) {
+  packageStartupMessage("Package 'future.BatchJobs' is deprecated and will be archived on CRAN. Please use 'future.batchtools' instead.")
+}
